<?php
/**
 * Backdrop Core ( functions-layouts.php )
 *
 * @package        Backdrop Core
 * @copyright      Copyright (C) 2018-2019. Benjamin Lu
 * @license        GNU General Public License v2 or later ( https://www.gnu.org/licenses/gpl-2.0.html )
 * @author         Benjamin Lu ( https://benjlu.com )
 */

/**
 * Define namespace
 */
namespace Benlumia007\Backdrop\ThemeLayout;

/**
 * Table of Content
 *
 *  1.0 - Customize ( Theme Layout ( $wp_customize ) )
 *  2.0 - Customize ( Theme Layout ( Validation ) )
 */

/**
 *
 * 1.0 - Customize ( Theme Layout ( $wp_customize ) )
 *
 * @param array $wp_customize a portfolio.
 */
function load_theme_layout( $wp_customize ) {
	if ( current_theme_supports( 'backdrop-theme-layout' ) ) {
		$wp_customize->add_section(
			'global_layout',
			array(
				'title'    => esc_html__( 'General Layout', 'individuality' ),
				'panel'    => 'theme_options',
				'priority' => 5,
			)
		);
		$wp_customize->add_setting(
			'global_layout',
			array(
				'default'           => 'left-sidebar',
				'sanitize_callback' => 'Benlumia007\Backdrop\ThemeLayout\sanitize_layouts',
				'transport'         => 'refresh',
				'type'              => 'theme_mod',
			)
		);
		$wp_customize->add_control(
			new Control_Radio_Image(
				$wp_customize,
				'global_layout',
				array(
					'label'       => esc_html__( 'General Layout', 'individuality' ),
					'description' => esc_html__( 'General Layout applies to all layouts that supports in this theme.', 'individuality' ),
					'section'     => 'global_layout',
					'settings'    => 'global_layout',
					'type'        => 'radio-image',
					'choices'     => array(
						'left-sidebar'  => get_theme_file_uri( '/vendor/benlumia007/backdrop-core/src/assets/images/2cl.png' ),
						'right-sidebar' => get_theme_file_uri( '/vendor/benlumia007/backdrop-core/src/assets/images/2cr.png' ),
						'no-sidebar'    => get_theme_file_uri( '/vendor/benlumia007/backdrop-core/src/assets/images/1col.png' ),
					),
				)
			)
		);
	}
}
add_action( 'customize_register', __NAMESPACE__ . '\load_theme_layout' );
/**
 *
 *  3.0 - Customize (Theme Layout (Validation))
 *
 * @param string $input ot a object.
 */
function sanitize_layouts( $input ) {
	$choices = array(
		'left-sidebar',
		'right-sidebar',
		'no-sidebar',
	);
	if ( in_array( $input, $choices, true ) ) {
		return $input;
	} else {
		return 'left-sidebar';
	}
}
